pub enum ContentBadge {
BULK,
GENERATED,
LAUNCHPAD,
PREMIUM,
STANDARD,
}Expand description
ContentBadge : A flag that provides additional information about an A+ Content document. A flag that provides additional information about an A+ Content document.
Variants
BULK
GENERATED
LAUNCHPAD
PREMIUM
STANDARD